==> nsafirstlibrary-1.0.0.tgz: package/resources/authorizations.js <==
'use strict'

// Include global module
var globals = require('../global');

//Declare token
var token;

//Declare url
var url;

module.exports = {

  // Login method request
  postAuthorizations: function (path, host, currentObject, success) {
 
    // Define basic authorization
    var auth = 'Basic ' + new globals.Buffer(currentObject.state.username + ':' + currentObject.state.password).toString('base64');

    // Assign url
    url = host + path;

    //Set request
    globals.https.post(url)
      .set('Authorization', auth)
      .set('Content-Type', 'application/json')
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  // Refresh login method request
  postRefreshAuthorizations: function (path, host, currentObject, success) {

    // Assign url
    url = host + path;

    // Define token authorization
    token = 'token ' + currentObject.state.refreshToken;

    //Set request
    globals.https.post(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  // Refresh login method request
  logout: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    // Define token authorization
    token = 'token ' + currentObject.state.refreshToken;

    //Set request
    globals.https.del(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  }

}

==> nsafirstlibrary-2.0.0.tgz: package/resources/authorizations.js <==
'use strict'

// Include global module
var globals = require('../global');

//Declare token
var token;

//Declare url
var url;

module.exports = {

  // Login method request
  postAuthorizations: function (path, host, currentObject, success) {

    // Define basic authorization
    var auth = 'Basic ' + new globals.Buffer(currentObject.state.username + ':' + currentObject.state.password).toString('base64');

    // Assign url
    url = host + path;

    //Set request
    globals.https.post(url)
      .set('Authorization', auth)
      .set('Content-Type', 'application/json')
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  // Refresh login method request
  postRefreshAuthorizations: function (path, host, refreshToken, currentObject, success) {

    // Assign url
    url = host + path;

    // Define token authorization
    token = 'token ' + refreshToken;

    //Set request
    globals.https.post(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  // Refresh login method request
  logout: function (path, host, refreshToken, currentObject, success) {

    // Assign Complete url
    url = host + path;

    // Define token authorization
    token = 'token ' + refreshToken;

    //Set request
    globals.https.del(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  }

}
